% Stile LaTeX per ---Ithaca: viaggio nella scienza--- una rivista di
% divulgazione e cultura scientifica edita dal Dipartimento di
% Matematica e Fisica "Ennio De Giorgi".
%
% Basato sullo stile "Two column color article",
% http://www.howtotex.com/.
%
% Basato sullo stile "article" del pacchetto KOMA-Script.
%
% (c) Francesco Paparella - 2012-2016.
%
\NeedsTeXFormat{LaTeX2e} 
\ProvidesClass{ithaca}[2016/10/15 v0.96] %la data DEVE avere la forma yyyy/mm/dd
\newcommand{\ncols}{twocolumn}
\DeclareOption{ItaEng}{
  \typeout{---*** Opzione ItaEng ***---.}
  \renewcommand{\ncols}{onecolumn}
  %L'ambiente 'sinossi' usa il pacchetto 'paracol' per definire
  %testi bilingue su due colonne affiancate. Per ora sono disponibili
  %solo italiano e inglese.
  \newenvironment{sinossi}
     {\begin{paracol}{2}}
     {\end{paracol}}
  %Riallinea il testo della colonna sinistra e della colonna destra.
  \newcommand{\riallinea}{\switchcolumn*}
  %A sinistra il testo italiano.
  \newcommand{\Ita}[1]{%
    \begin{leftcolumn}#1\end{leftcolumn}%
  }
  %A destra quello inglese.
  \newcommand{\Eng}[1]{%
    \selectlanguage{english}%
    \begin{rightcolumn}#1\end{rightcolumn}%
    \selectlanguage{italian}%
  }
}
\ProcessOptions\relax
\LoadClass[a4paper,%
           fontsize=11pt,%
           DIV=10,%
           \ncols
           ]{scrartcl}
%
%\RequirePackage{pdfcolparallel} %this is actually needed only if ItaEng is 
                                %active. But I get an error if I put it into
                                %\DeclareOption
\RequirePackage{paracol} 
%
% Spazio fra le colonne
\setlength{\columnsep}{2cc}
%
%\RequirePackage{ae,aecompl} %da usare solo in emergenza, se non fosse
                             %disponibile mathpazo ed il font 'palatino'
%\RequirePackage[sc]{mathpazo} %Carica il tipo URW Palladio (un clone del font 'palatino')
\RequirePackage{tgpagella}     %Pagella è una versione migliorata di mathpazo
\linespread{1.05}              %Palatino beneficia di un'interlinea più larga
%\RequirePackage[charter, uppercase=upright]{mathdesign} %charter è un po' 
                                                         %evanescente nel testo
                                                         %normale
% Seleziona i tipi adatti per l'uso con le lingue europee.
\RequirePackage[T1]{fontenc}
% Permette l'uso di lettere accentate nel testo (es. "è" al posto di "\`e")
\RequirePackage[utf8]{inputenc}
%
% Sillabazione italiana.
\RequirePackage[english,italian]{babel}
%
% Margini
\RequirePackage[a4paper, left=20mm, right=20mm, top=15mm, bottom=30mm]{geometry}
%
% Tipografia migliorata.
\RequirePackage[protrusion=true,expansion=true]{microtype}
%
% Pacchetti matematici AMS.
\RequirePackage{amsmath,amsfonts,amsthm,amssymb}
%
% Abilita pdflatex e l'inserimento di figure.
\RequirePackage[pdftex]{graphicx}
%
% Converte in .pdf le figure in .eps.
\RequirePackage{epstopdf}
%
% Abilita l'uso di colori richiamati con i nomi svg.
\RequirePackage[svgnames]{xcolor}
%
% Il sistema di didascalie di KOMA-script è particolarmente barocco.
% Uso il pacchetto "caption" che è più snello.
\RequirePackage[hang,small,labelfont=bf,up,textfont=it,up]{caption}
\renewcommand{\captionlabelfont}{\color{DarkGoldenrod}\usefont{T1}{phv}{b}{n}}
%
% Tipografia degli indirizzi web
%\RequirePackage{url} %sostituito con hyperref
%
% Riferimenti ipertestuali
\definecolor{DarkerGoldenrod}{rgb}{0.48, 0.35, 0.02}%
\RequirePackage[hyperfootnotes=false,%
                hyperfigures=false,%
                colorlinks=true,%
                linkcolor=black,%
                filecolor=black,%
                urlcolor=DarkerGoldenrod,%
                citecolor=DarkerGoldenrod,%
%               pagebackref=true%
                ]{hyperref}
%\RequirePackage{hyperref}
%
% Subfigure
\RequirePackage{subfig}
%
% Tabelle più belle.
\RequirePackage{booktabs}
%
% Dimensioni a scelta dei caratteri.
\RequirePackage{fix-cm}
%
% Personalizzazioni del titolo e dei titoli di sezione 
\RequirePackage{sectsty}
%
\allsectionsfont{%
  % Carattere delle sotto e sotto-sotto sezioni
  % bch-b-n: CharterBT-Bold font
  \usefont{T1}{phv}{b}{n}
  \color{DarkRed}
}
\sectionfont{%
  % Carattere del comando \section
  % bch-b-n: CharterBT-Bold font
  \usefont{T1}{phv}{b}{n}
  \color{DarkRed}
}
%
% Elimino la numerazione da tutte le sezioni (e sottosezioni, etc.)
\setcounter{secnumdepth}{0}
%
% Linea orizzontale giallo scura per il titolo
\newcommand{\HorRule}{\color{DarkGoldenrod}%
  \rule{\linewidth}{1pt}%
}
%
% Eventuale dotta citazione da mettere sotto al titolo
\def\@DottaCita{}
\newcommand{\dottacitazione}[2]{%
  \def\@DottaCita{%
  \begin{flushright}
    \vspace{20pt}
    \begin{minipage}{0.475\textwidth}
    \fontsize{9}{12}% 
    \usefont{T1}{bch}{m}{it}%
    \color{black}%
    \selectfont%
    #1\\%
    \fontsize{9}{12}% 
    \usefont{T1}{bch}{b}{n}%
    \color{DarkRed}%
    \selectfont{\color{DarkGoldenrod}\hrulefill}~#2%
    \end{minipage}\vspace{-10pt}%
  \end{flushright}%
  }%
}
\def\@TheSeries{}
\newcommand{\serie}[1]{%
  \def\@TheSeries{%
    \fontsize{22}{25}% 
    \usefont{T1}{phv}{b}{n}%
    \color{DarkGoldenrod}%
    \selectfont%
    \vspace{-5pt}
    #1\\%
   }%
}
%
% Ridefinisco il titolo per avere la possibilità di specificare
% opzionalmente un titolo corto (non ho capito se era già previsto
% in koma-script), e per cambiare carattere, colori, etc.
\makeatletter
\def\@NoAuthor{}
\title{%
  \vspace{-30pt}%
  \begin{flushleft}%
    \HorRule%
    \\%
    \@TheSeries%
    \fontsize{40}{55}% 
    \usefont{T1}{phv}{b}{n}%
    \color{DarkRed}%
    \selectfont% 
    \@TheTitle%
    \\%
  \end{flushleft}%
  \@DottaCita%
  \@NoAuthor%
}
\renewcommand{\title}[2][\@TheTitle]{\def\@ShortTitle{#1}\def\@TheTitle{#2}}
%
% Ridefinisco l'autore per cambiare carattere, colori, etc.
% Per avere più autori con rispettive affiliazioni definisco anche 
% "\name" e "\affiliation" da usarsi all'interno di \author{}.
\author{%
  \hspace{-4pt}%
  \begin{tabular*}{\textwidth}{@{}ll@{}}%
  \@TheAuthor%
  \end{tabular*}%
  \\%
  \hspace{-9pt}%
  \HorRule%
}
%
\renewcommand{\author}[1]{\def\@TheAuthor{#1}}
\newcommand{\name}[1]{\large%
  \lineskip 0.5em%
  \usefont{T1}{phv}{b}{sl}%
  \color{DarkRed}%
  #1&%
}
\newcommand{\affiliation}[1]{%
  \hskip 0.75em%
  \footnotesize%
  \usefont{T1}{phv}{m}{sl}%
  \color{Black}% 
  \begin{minipage}{\linewidth}%
  #1%
  \end{minipage}%
  \\%
}
% Se l'articolo non ha autori, bisogna specificare '\noauthor'
\newcommand{\noauthor}{\def\@TheAuthor{}%
  \def\@NoAuthor{\vspace{-22pt}}
}
\makeatother
%
% Elimino la data
\date{}
%
% Testate e piè di pagina.
\RequirePackage{fancyhdr}
\pagestyle{fancy}
% Testata (vuota)
\lhead{}
\chead{}
\rhead{}
\makeatletter
% Piè di pagina
\RequirePackage{textcomp} % simboli per il testo (p.es. "\textbullet")
\def\@TheNumber{X}
\def\@TheYear{XXXX}
\newcommand{\NUMERO}[1]{\def\@TheNumber{#1}}
\newcommand{\ANNO}[1]{\def\@TheYear{#1}}
\lfoot{\footnotesize \textbf{Ithaca:~Viaggio~nella~Scienza~\@TheNumber,~\@TheYear}~~\textbullet~~\@ShortTitle}
\makeatother
\cfoot{}
\rfoot{\footnotesize \thepage}
\renewcommand{\headrulewidth}{0.0pt}
\renewcommand{\footrulewidth}{0.4pt}
%
% Lettera iniziale ingrandita.
% N.B. "\linewidth\hsize" risolve problemi col testo multilingua a 2 colonne.
\usepackage{lettrine}
\newcommand{\initial}[1]{%
     \linewidth\hsize\lettrine[lines=3,lhang=0.,nindent=0em,%
                               lraise=0.0,loversize=-0.0]{%
     				\color{DarkGoldenrod}%
     				{#1}}{}}%
%
% Definisco una versione personalizzata di "\maketitle" per
% imporre lo stile di pagina "fancy" anche alla prima pagina.
% Utile anche per future personalizzazioni.
\newcommand{\gscmaketitle}{%
  \maketitle%
  \thispagestyle{fancy}%
}
\newcommand{\ithacamaketitle}{\gscmaketitle}
%
% Definisco una versione personalizzata di "\abstract".
% La seguente macro (puro TeX) selezione il primo carattere
% del testo dell'abstract e passarlo al comando "\initial"
% per tipografarlo in grande.
\makeatletter
\def\splitfirstchar#1#2\sentinel{\initial{#1}{%
  \color{DarkRed}%
  %\usefont{T1}{phv}{b}{n}%
  \usefont{T1}{bch}{b}{n}% il palatino bold non è un gran che, uso il charter
                         % per l'abstract
  %\large{#2}%
  \normalsize{#2}%
}}
\RequirePackage{setspace} %cambio l'interlinea dell'abstract
\renewcommand{\abstract}[1]{%
  \begin{spacing}{1.2}%
    \splitfirstchar#1\sentinel%
  \end{spacing}%
  \vspace{1ex}%
  \@afterindentfalse
  \@afterheading
}
%
% Comando per inserire una figura in una colonna
% N.B. le doppie graffe nelle didascalie servono per evitare pasticci con
% \url e \href del pacchetto hyperref
\newcommand{\ColumnFigure}[2]{%
  \begin{figure}[ht]
    \includegraphics[width=\columnwidth]{#1}
    \caption{{#2}}
  \end{figure}
}
%
% Comando per inserire una figura a larghezza di pagina
\newcommand{\WideFigure}[2]{%
 \begin{center}
  \begin{figure*}[ht]
    \includegraphics[width=\textwidth]{#1}
    \caption{{#2}}
  \end{figure*}
\end{center}
}
%
% Figura a largezza di pagina con didascalia a fianco
\usepackage{calc}
\newcommand{\WideFigureSideCaption}[3][0.7]{%
  \begin{figure*}[ht]
    \begin{minipage}[c][\totalheight][b]{#1\textwidth}
      \includegraphics[width=\textwidth]{#2}%
    \end{minipage}%
    \hfill%
    %\begin{minipage}[c][\totalheight][b]{0.275\textwidth}
    \setlength{\captionwidth}{\textwidth-#1\textwidth-0.025\textwidth}
    \begin{minipage}[c][\totalheight][b]{\captionwidth}
      \vspace{-2ex}
      \captionsetup{format=plain}
      \caption{{#3}}
    \end{minipage}%
  \end{figure*}
}
%
% Box con sfondo colorato
%\definecolor{BoxBgColor}{rgb}{0.94117647,  0.88235294,  0.18823529}%Dandelion
%\definecolor{BoxBgColor}{rgb}{1.,  0.94901961,  0.34901961}%Lavender Blush
%\definecolor{BoxBgColor}{rgb}{0.98039216,  0.84313725,  0.4}%Deep Champagne
%\definecolor{BoxBgColor}{rgb}{1.,  0.85882353,  0.50980392}%Mustard
\definecolor{BoxBgColor}{rgb}{1.,  1.,  0.65}%
\usepackage{tikz}
\newcommand\boxtitle[1]{
    \node[black!25!white] at (+0.03,-0.03) {
        \textbf{#1}
    };
    \node[black!50!white] at (+0.015,-0.015) {
        \textbf{#1}
    };
    \node[DarkRed] at (0,0) {
        \textbf{#1}
    };
}
% Box su colonna singola: la minipagina nella minipagina è un trucco per
% regolare i margini laterali del testo. 
\newcommand{\ocbox}[2]{%
\begin{figure}[t]%
  \fcolorbox{DarkGoldenrod}{BoxBgColor}{%
    \begin{minipage}[t]{1.0\columnwidth}
      \begin{center}%
        \begin{minipage}[t]{0.85\columnwidth}%
          \vspace{3ex}%
          \begin{center}
            \begin{tikzpicture}[remember picture,overlay]   
              \boxtitle{#1}%
            \end{tikzpicture} 
          \end{center}
          #2%
          \vspace{1ex}%
        \end{minipage}%
      \end{center}%
    \end{minipage}%
  }%
\end{figure}
}
% Box su due colonne
\newcommand{\tcbox}[2]{%
\begin{figure*}[t]%
  \fcolorbox{DarkGoldenrod}{BoxBgColor}{%
    \begin{minipage}[t]{1.0\textwidth}
      \begin{center}%
        \begin{minipage}[t]{0.925\textwidth}%
          \vspace{3ex}%
          \begin{center}
            \begin{tikzpicture}[remember picture,overlay]   
              \boxtitle{#1}%
            \end{tikzpicture} 
          \end{center}
          #2%
          \vspace{4ex}%
        \end{minipage}%
      \end{center}%
    \end{minipage}%
  }%
\end{figure*}
}
%
% Questo dovrebbe migliorare il piazzamento automatico dei float.
% http://www.howtotex.com/tips-tricks/control-float-placement/
% http://mintaka.sdsu.edu/GF/bibliog/latex/floats.html
\renewcommand{\textfraction}{0}
\renewcommand{\topfraction}{1}
\renewcommand{\bottomfraction}{1}
%\renewcommand{\floatpagefraction}{0.85}
\renewcommand{\floatpagefraction}{0.99}
\setcounter{dbltopnumber}{2}    % for 2-column pages
\renewcommand{\dbltopfraction}{0.8}	% fit big float above 2-col. text
%\afterpage{\clearpage} after a float may help a lot in float placement
\RequirePackage{afterpage} 
%
%
% font ornamentali
\RequirePackage{pifont}
\RequirePackage{fourier-orns}
% Bibliografia (modifiedfrom http://stackoverflow.com/questions/1037905/bibliography-as-section-in-latex-bibtex)
\makeatletter
\renewenvironment{thebibliography}[1]
     {%\section*{\bibname}% 
      %\@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      {\noindent\color{DarkGoldenrod}
        \begin{center}
          \center\decothreeright\qquad\ding{77}\qquad\decothreeleft
        \end{center}
      }
      \vspace{2ex}%
      \footnotesize%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist%
      \vspace{1ex}%
      {\color{DarkGoldenrod}
        \hrulefill\qquad%
        \decofourright\qquad\starredbullet\qquad\decofourleft%
        \qquad\hrulefill}%
      \vspace{4ex}%
    }
\makeatother
%
% Nuovi comandi per la bibliografia.
% Citazione articoli:
%    \refer{autori}{titolo}{rivista}{vol}{anno}{pagine}
\newcommand{\refer}[6]{{ #1:\newblock} \textsl{ #2,\newblock}
{\  #3,}{\ #4}{\ (#5)}{\ #6.}}
% Citazione libri:
%    \referbook{autori}{titolo}{editore}{citta}{anno}
\newcommand{\referbook}[5]{{ #1:\newblock}
\textsl{ #2 \newblock}
{\ #3,\newblock}{\ #4}{\ (#5).}}
%
% Comando da usare se non c'è la bibliografia
\newcommand{\nobibliography}{
  \vspace{2ex}%
  {\color{DarkGoldenrod}
    \noindent\hrulefill\qquad%
    \decofourright\qquad\starredbullet\qquad\decofourleft%
    \qquad\hrulefill}%
  \vspace{3ex}%
}
% Se in futuro necessari, caricare altri pacchetti per la bibliografia
% a questo punto.
%
% Biografia degli autori 
%
\newcommand\AuthorsBio[2]{
  {\noindent\color{DarkRed}\textbf{#1: }}{#2}\par%
  \vspace{1.5ex}%
}
%
%
%
%
%
% %http://tex.stackexchange.com/questions/25614/background-image-for-minipage
% \newsavebox\mysavebox
% \newenvironment{imgminipage}[2][]{%
%    \def\imgcmd{\includegraphics[width=\wd\mysavebox,height=\dimexpr\ht\mysavebox+\dp\mysavebox\relax,#1]{#2}}%
%    \begin{lrbox}{\mysavebox}%
%    \begin{minipage}%
% }{%
%    \end{minipage}
%    \end{lrbox}%
% %   \sbox\mysavebox{\fbox{\usebox\mysavebox}}%
%    \sbox\mysavebox{\usebox\mysavebox}%
%    \mbox{\rlap{\raisebox{-\dp\mysavebox}{\imgcmd}}\usebox\mysavebox}%
% }
